about summary refs log tree commit diff
path: root/pkgs/test
diff options
context:
space:
mode:
authorRobert Hensing <robert@roberthensing.nl>2023-01-25 17:09:33 +0100
committerRobert Hensing <robert@roberthensing.nl>2023-01-29 09:51:55 +0100
commita010129bf87c2afcb2f60db410cc535fef299f8c (patch)
tree1c23ffd68ab8df289bec50669e9d4ef6cc3922da /pkgs/test
parent90fdbf5f394f3bb7d49992702157df7d93056055 (diff)
pkg-configPackages -> defaultPkgConfigPackages
This better reflects the purpose of the package set, while leaving
room for a fancier, more complete implementation of the concept,
with a nicer name.
Diffstat (limited to 'pkgs/test')
-rw-r--r--pkgs/test/default.nix4
-rw-r--r--pkgs/test/pkg-config-packages.nix4
2 files changed, 4 insertions, 4 deletions
diff --git a/pkgs/test/pkg-config-packages.nix b/pkgs/test/pkg-config-packages.nix
index be046c8cacca2..8cb6cc57753f2 100644
--- a/pkgs/test/pkg-config-packages.nix
+++ b/pkgs/test/pkg-config-packages.nix
@@ -1,8 +1,8 @@
-{ lib, pkg-config, pkg-configPackages, runCommand }:
+{ lib, pkg-config, defaultPkgConfigPackages, runCommand }:
 let
   inherit (lib.strings) escapeNixIdentifier;
 
-  allTests = lib.mapAttrs (k: v: if v == null then null else makePkgConfigTestMaybe k v) pkg-configPackages;
+  allTests = lib.mapAttrs (k: v: if v == null then null else makePkgConfigTestMaybe k v) defaultPkgConfigPackages;
 
   # nix-build rejects attribute names with periods
   # This will build those regardless.
diff --git a/pkgs/test/default.nix b/pkgs/test/default.nix
index 82134b051d4e5..72b22f7f68658 100644
--- a/pkgs/test/default.nix
+++ b/pkgs/test/default.nix
@@ -51,9 +51,9 @@ with pkgs;
 
   php = recurseIntoAttrs (callPackages ./php {});
 
-  pkg-configPackages =
+  defaultPkgConfigPackages =
     let
       # pkg-configPackages test needs a Nixpkgs with allowUnsupportedPlatform
       # in order to filter out the unsupported packages without throwing any errors
       # tryEval would be too fragile, masking different problems as if they're
       # unsupported platform problems.
@@ -51,9 +51,9 @@ with pkgs;
     let
-      # pkg-configPackages test needs a Nixpkgs with allowUnsupportedPlatform
+      # defaultPkgConfigPackages test needs a Nixpkgs with allowUnsupportedPlatform
       # in order to filter out the unsupported packages without throwing any errors
       # tryEval would be too fragile, masking different problems as if they're